#pragma once

namespace wrtr
{
    void print(const char* message);
} // namespace wrtr